@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 
 from django.db import migrations, models
 
@@ -19,6 +18,6 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='contact',
             name='same_as',
-            field=models.ForeignKey(default=None, blank=True, to='Crm.SameAs', null=True, verbose_name='same as'),
+            field=models.ForeignKey(default=None, blank=True, to='Crm.SameAs', null=True, verbose_name='same as', on_delete=models.CASCADE),
         ),
     ]
