@@ -30,6 +30,11 @@ from balafon.utils import now_rounded, logger, validate_rgb
 from balafon.Users.models import Favorite
 
 
+class ConfirmedManager(models.Manager):
+    def get_queryset(self):
+        return super().get_queryset().filter(confirmed=True)
+
+
 class NamedElement(models.Model):
     """Base class for models with a name field"""
     name = models.CharField(_('Name'), max_length=200)
@@ -327,6 +332,14 @@ class Entity(AddressModel):
     is_single_contact = models.BooleanField(_("is single contact"), default=False)
     
     favorites = GenericRelation(Favorite)
+
+    confirmed = models.BooleanField(
+        default=True, verbose_name=_('confirmed'), db_index=True,
+        help_text=_('For contact created from subscription form, we need to wait for confirmation by email link')
+    )
+
+    all_objects = models.Manager()  # The default manager.
+    objects = ConfirmedManager()
     
     def save(self, *args, **kwargs):
         """save"""
@@ -375,17 +388,23 @@ class Entity(AddressModel):
     def get_safe_logo(self):
         """get entity logo or default one"""
         if self.logo:
-            width, height = self.logo.width, self.logo.height
-            image_format = "64" if width > height else "x64"
-            return sorl_thumbnail.backend.get_thumbnail(self.logo.file, image_format, crop='center').url
+            try:
+                width, height = self.logo.width, self.logo.height
+                image_format = "64" if width > height else "x64"
+                return sorl_thumbnail.backend.get_thumbnail(self.logo.file, image_format, crop='center').url
+            except FileNotFoundError:
+                pass
         else:
             return self.default_logo()
     
     def default_logo(self):
         """get default logo"""
         if self.type and self.type.logo:
-            file_ = sorl_thumbnail.backend.get_thumbnail(self.type.logo.file, "64x64", crop='center')
-            return file_.url
+            try:
+                file_ = sorl_thumbnail.backend.get_thumbnail(self.type.logo.file, "64x64", crop='center')
+                return file_.url
+            except FileNotFoundError:
+                pass
         
         if self.is_single_contact:
             logo = "img/single-contact.png"
@@ -396,14 +415,17 @@ class Entity(AddressModel):
     
     def get_logo_center_style(self):
         """get logo style to apply to img html tag to get the logo centered"""
-        if self.logo:
-            width, height = self.logo.width, self.logo.height
-            if width > height:
-                width, height = 64, height * 64 / width
-                return mark_safe('style="margin: {0}px 0"'.format((64 - height) / 2))
-            else:
-                width, height = width * 64 / height, height
-                return mark_safe('style="margin-left: 0 {0}px"'.format((64 - width) / 2))
+        try:
+            if self.logo:
+                width, height = self.logo.width, self.logo.height
+                if width > height:
+                    width, height = 64, height * 64 / width
+                    return mark_safe('style="margin: {0}px 0"'.format((64 - height) / 2))
+                else:
+                    width, height = width * 64 / height, height
+                    return mark_safe('style="margin-left: 0 {0}px"'.format((64 - width) / 2))
+        except FileNotFoundError:
+            pass
                 
     def get_absolute_url(self):
         """url to the entity page"""
@@ -588,7 +610,7 @@ class Relationship(TimeStampedModel):
     class Meta:
         verbose_name = _('relationship')
         verbose_name_plural = _('relationships')
-    
+
 
 class Contact(AddressModel):
     """a contact : how to contact a physical person. A physical person may have several contacts"""
@@ -652,6 +674,14 @@ class Contact(AddressModel):
 
     favorite_language = models.CharField(_("favorite language"), max_length=10, default="", blank=True)
 
+    confirmed = models.BooleanField(
+        default=True, verbose_name=_('confirmed'), db_index=True,
+        help_text=_('For contact created from subscription form, we need to wait for confirmation by email link')
+    )
+
+    all_objects = models.Manager()  # The default manager.
+    objects = ConfirmedManager()
+
     def get_view_url(self):
         if self.entity.is_single_contact:
             absolute_url = reverse('crm_view_entity', args=[self.entity.id])
@@ -891,9 +921,12 @@ class Contact(AddressModel):
         fullname = "{0} {1}".format(self.lastname, self.firstname).strip()
         if not fullname:
             fullname = self.email
-        if self.entity.is_single_contact:
+        try:
+            if self.entity.is_single_contact:
+                return fullname
+            return "{0} ({1})".format(fullname, self.entity.name)
+        except Exception:
             return fullname
-        return "{0} ({1})".format(fullname, self.entity.name)
 
     def get_gender_text(self):
         if self.gender_title:
@@ -1399,6 +1432,7 @@ class TeamMember(models.Model):
     )
     name = models.CharField(max_length=100, verbose_name=_("name"))
     active = models.BooleanField(default=True, verbose_name=(_("active")))
+    ordering = models.IntegerField(default=0, verbose_name=_('ordering'))
 
     def __str__(self):
         return self.name
@@ -1406,6 +1440,7 @@ class TeamMember(models.Model):
     class Meta:
         verbose_name = _('team member')
         verbose_name_plural = _('team members')
+        ordering = ['ordering', 'name']
 
 
 class ActionMenu(models.Model):
