@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """unit testing"""
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
 from balafon.Crm.tests import BaseTestCase
 
