@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 """unit testing"""
 
-from cStringIO import StringIO
-import json
 import sys
 
 from django.core import management
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
 from coop_cms.tests import BeautifulSoup
+from coop_cms.moves import StringIO
 from model_mommy import mommy
 
+from balafon.unit_tests import response_as_json
 from balafon.Crm import models
 from balafon.Crm.tests import BaseTestCase
 
@@ -247,8 +247,8 @@ class SameAsPriorityTest(BaseTestCase):
 
         response = self.client.post(url, data={'priority': 2})
         self.assertEqual(200, response.status_code)
-        self.assertEqual(
-            response.content,
+        self.assertContains(
+            response,
             '<script>$.colorbox.close(); window.location="{0}";</script>'.format(contact2.get_absolute_url()),
         )
 
@@ -279,8 +279,8 @@ class SameAsPriorityTest(BaseTestCase):
 
         response = self.client.post(url, data={'priority': 1})
         self.assertEqual(200, response.status_code)
-        self.assertEqual(
-            response.content,
+        self.assertContains(
+            response,
             '<script>$.colorbox.close(); window.location="{0}";</script>'.format(contact2.get_absolute_url()),
         )
 
@@ -318,8 +318,8 @@ class SameAsPriorityTest(BaseTestCase):
 
         response = self.client.post(url, data={'priority': 2})
         self.assertEqual(200, response.status_code)
-        self.assertEqual(
-            response.content,
+        self.assertContains(
+            response,
             '<script>$.colorbox.close(); window.location="{0}";</script>'.format(contact1.get_absolute_url()),
         )
 
@@ -359,8 +359,8 @@ class SameAsPriorityTest(BaseTestCase):
 
         response = self.client.post(url, data={'priority': 3})
         self.assertEqual(200, response.status_code)
-        self.assertEqual(
-            response.content,
+        self.assertContains(
+            response,
             '<script>$.colorbox.close(); window.location="{0}";</script>'.format(contact2.get_absolute_url()),
         )
 
@@ -398,8 +398,8 @@ class SameAsPriorityTest(BaseTestCase):
 
         response = self.client.post(url, data={'priority': 4})
         self.assertEqual(200, response.status_code)
-        self.assertEqual(
-            response.content,
+        self.assertContains(
+            response,
             '<script>$.colorbox.close(); window.location="{0}";</script>'.format(contact1.get_absolute_url()),
         )
 
@@ -805,7 +805,6 @@ class RemoveSameAsTest(BaseTestCase):
         self.assertEqual(contact1.same_as_priority, 0)
 
 
-
 class FindSameAsTest(BaseTestCase):
 
     def test_find_same_as(self):
@@ -817,7 +816,7 @@ class FindSameAsTest(BaseTestCase):
         buf = StringIO()
         sysout = sys.stdout
         sys.stdout = buf
-        management.call_command('find_same_as', verbosity=0, interactive=False, stdout=buf)
+        management.call_command('find_same_as', verbosity=0, stdout=buf)
         buf.seek(0, 0)
         sys.stdout = sysout
         self.assertEqual(2, len(buf.readlines()))
@@ -831,7 +830,7 @@ class FindSameAsTest(BaseTestCase):
         buf = StringIO()
         sysout = sys.stdout
         sys.stdout = buf
-        management.call_command('find_same_as', "SameAs", verbosity=0, interactive=False, stdout=buf)
+        management.call_command('find_same_as', "SameAs", verbosity=0, stdout=buf)
         buf.seek(0, 0)
         sys.stdout = sysout
         self.assertEqual(2, len(buf.readlines()))
@@ -855,7 +854,7 @@ class FindSameAsTest(BaseTestCase):
         buf = StringIO()
         sysout = sys.stdout
         sys.stdout = buf
-        management.call_command('find_same_as', "SameAs", verbosity=0, interactive=False, stdout=buf)
+        management.call_command('find_same_as', "SameAs", verbosity=0, stdout=buf)
         buf.seek(0, 0)
         sys.stdout = sysout
         self.assertEqual(2, len(buf.readlines()))
@@ -878,7 +877,7 @@ class FindSameAsTest(BaseTestCase):
         buf = StringIO()
         sysout = sys.stdout
         sys.stdout = buf
-        management.call_command('find_same_as', "SameAs", verbosity=0, interactive=False, stdout=buf)
+        management.call_command('find_same_as', "SameAs", verbosity=0, stdout=buf)
         buf.seek(0, 0)
         sys.stdout = sysout
         self.assertEqual(2, len(buf.readlines()))
@@ -910,7 +909,7 @@ class SameAsSuggestionApiTest(BaseTestCase):
         response = self.client.post(url, data=data)
 
         self.assertEqual(response.status_code, 200)
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
         self.assertEqual(0, len(resp_data))
 
     def test_lastname(self):
@@ -927,7 +926,7 @@ class SameAsSuggestionApiTest(BaseTestCase):
         response = self.client.post(url, data=data)
 
         self.assertEqual(response.status_code, 200)
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
 
         self.assertEqual(1, len(resp_data))
         self.assertEqual(resp_data[0]['id'], contact2.id)
@@ -948,7 +947,7 @@ class SameAsSuggestionApiTest(BaseTestCase):
         response = self.client.post(url, data=data)
 
         self.assertEqual(response.status_code, 200)
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
         self.assertEqual(1, len(resp_data))
         self.assertEqual(resp_data[0]['id'], contact1.id)
         self.assertNotEqual(resp_data[0]['fullname'], '')
@@ -969,7 +968,7 @@ class SameAsSuggestionApiTest(BaseTestCase):
         response = self.client.post(url, data=data)
 
         self.assertEqual(response.status_code, 200)
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
         self.assertEqual(2, len(resp_data))
         resp_data = sorted(resp_data, key=lambda contact: contact['id'])
         self.assertEqual(resp_data[0]['id'], contact1.id)
@@ -993,7 +992,7 @@ class SameAsSuggestionApiTest(BaseTestCase):
         response = self.client.post(url, data=data)
 
         self.assertEqual(response.status_code, 200)
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
         self.assertEqual(1, len(resp_data))
         resp_data = sorted(resp_data, key=lambda contact: contact['id'])
         self.assertEqual(resp_data[0]['id'], contact1.id)
@@ -1015,7 +1014,7 @@ class SameAsSuggestionApiTest(BaseTestCase):
         response = self.client.post(url, data=data)
 
         self.assertEqual(response.status_code, 200)
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
         self.assertEqual(1, len(resp_data))
         resp_data = sorted(resp_data, key=lambda contact: contact['id'])
         self.assertEqual(resp_data[0]['id'], contact2.id)
@@ -1039,7 +1038,7 @@ class SameAsSuggestionApiTest(BaseTestCase):
         response = self.client.post(url, data=data)
 
         self.assertEqual(response.status_code, 200)
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
         self.assertEqual(2, len(resp_data))
         resp_data = sorted(resp_data, key=lambda contact: contact['id'])
         self.assertEqual(resp_data[0]['id'], contact1.id)
