@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-import floppyforms as forms
+import floppyforms.__future__ as forms
 
 
 class CityAutoComplete(forms.HiddenInput):
