@@ -28,6 +28,7 @@ from balafon.Crm.models import (
 )
 from balafon.Crm.widgets import CityAutoComplete
 from balafon.Emailing import models
+from balafon.Emailing.settings import notify_subscription_on_confirmation
 from balafon.Emailing.utils import (
     create_subscription_action, send_notification_email, get_language, subscribe_contact_to_newsletter
 )
@@ -149,6 +150,7 @@ class NewNewsletterForm(BsForm):
     template = forms.ChoiceField(label=_("Template"), choices=get_newsletter_templates(None, None))
     source_url = forms.URLField(label=_('Source URL'), required=False)
     content = forms.CharField(label=_('Content'), required=False, widget=forms.HiddenInput())
+    site = forms.ModelChoiceField(queryset=Site.objects.all(), label=_('Site'))
     
     def __init__(self, *args, **kwargs):
         super(NewNewsletterForm, self).__init__(*args, **kwargs)
@@ -347,7 +349,7 @@ class SubscribeForm(ModelFormWithCity, SubscriptionTypeFormMixin):
         # Do not display (Mrs and M) gender on subscribe form
         if 'gender' in self.fields:
             self.fields['gender'].choices = [
-                (models.Contact.GENDER_NOT_SET, _('')),
+                (models.Contact.GENDER_NOT_SET, ''),
                 (models.Contact.GENDER_MALE, ugettext('Mr')),
                 (models.Contact.GENDER_FEMALE, ugettext('Mrs')),
             ]
@@ -606,7 +608,8 @@ class MinimalSubscribeForm(BetterBsModelForm, SubscriptionTypeFormMixin):
         if subscriptions:
             create_subscription_action(contact, subscriptions)
 
-        # send an email
-        send_notification_email(request, contact, [], '')
+        if not notify_subscription_on_confirmation():
+            # send an email
+            send_notification_email(request, contact, [], '')
 
         return contact
