@@ -10,13 +10,14 @@ from balafon.Profile.utils import check_category_permission
 
 class EmailModelBackend(ModelBackend):
     def authenticate(self, username=None, password=None, email=None):
+        email = email or username
+        kwargs = {
+            'is_active': True,
+            'email': email.strip(),
+        }
+
         try:
-            email = email or username
-            user = User.objects.get(email=email.strip())
-            
-            if not user.is_active:
-                return None
-            
+            user = User.objects.get(**kwargs)
             if user.check_password(password):
                 return user
             
@@ -24,9 +25,9 @@ class EmailModelBackend(ModelBackend):
             return None
 
         except User.MultipleObjectsReturned:
-            for _user in User.objects.filter(email=email.strip()):
-                if _user.check_password(password):
-                    return _user
+            for next_user in User.objects.filter(**kwargs):
+                if next_user.check_password(password):
+                    return next_user
             return None
 
 
