@@ -8,14 +8,14 @@ from django.utils.translation import ugettext, ugettext_lazy as _
 import floppyforms.__future__ as forms
 
 from balafon.Crm.models import Contact, EntityType
-from balafon.Crm.forms import ModelFormWithCity
+from balafon.Crm.forms import ModelFormWithCity, BillingModelFormWithCity
 from balafon.Crm.widgets import CityAutoComplete
 from balafon.Emailing.forms import SubscriptionTypeFormMixin
-from balafon.Profile.models import ContactProfile
+from balafon.Profile.models import ContactProfile, ContactProfileCustomField
 from balafon.settings import has_entity_on_registration_form, get_registration_accept_terms_of_use_link
 
 
-class ProfileForm(ModelFormWithCity, SubscriptionTypeFormMixin):
+class ProfileForm(BillingModelFormWithCity, SubscriptionTypeFormMixin):
     """A form for updating user profile"""
     city = forms.CharField(
         required=False,
@@ -41,6 +41,19 @@ class ProfileForm(ModelFormWithCity, SubscriptionTypeFormMixin):
         super(ProfileForm, self).__init__(*args, **kwargs)
         self._add_subscription_types_field(contact=self.instance)
 
+        if 'gender' in self.fields:
+            # do not display Mrs and Mr
+            choices = []
+            if not self.fields['gender'].required:
+                choices = [
+                    (Contact.GENDER_NOT_SET, ''),
+                ]
+            choices += [
+                (Contact.GENDER_MALE, ugettext('Mr')),
+                (Contact.GENDER_FEMALE, ugettext('Mrs')),
+            ]
+            self.fields['gender'].choices = choices
+
 
 class EmailField(forms.EmailField):
     """This field avoid duplicate emails"""
@@ -92,13 +105,13 @@ class UserRegistrationForm(ModelFormWithCity, SubscriptionTypeFormMixin):
         if 'gender' in self.fields:
             # do not display Mrs and Mr
             self.fields['gender'].choices = [
-                (Contact.GENDER_NOT_SET, _('Gender')),
+                (Contact.GENDER_NOT_SET, ''),
                 (Contact.GENDER_MALE, ugettext('Mr')),
                 (Contact.GENDER_FEMALE, ugettext('Mrs')),
             ]
 
         if 'entity_type' in self.fields:
-            self.fields['entity_type'].choices = [(0, ugettext('Individual'))]+[
+            self.fields['entity_type'].choices = [(0, ugettext('Individual'))] + [
                 (et.id, et.name) for et in EntityType.objects.filter(subscribe_form=True)
             ]
         if not has_entity_on_registration_form():
@@ -115,13 +128,19 @@ class UserRegistrationForm(ModelFormWithCity, SubscriptionTypeFormMixin):
             )
         self._add_subscription_types_field()
 
-    def clean_entity(self, ):
+    def clean_entity(self):
         entity_type = self.cleaned_data.get('entity_type', None)
         entity = self.cleaned_data['entity']
         if entity_type:
             if not entity:
                 raise ValidationError(_("{0}: Please enter a name".format(entity_type)))
         return entity
+
+    def clean_gender(self):
+        gender = int(self.cleaned_data.get('gender', None) or Contact.GENDER_NOT_SET)
+        if self.fields['gender'].required and gender == Contact.GENDER_NOT_SET:
+            raise ValidationError(_("This field is required"))
+        return gender
         
     def clean_entity_type(self):
         try:
@@ -144,6 +163,15 @@ class UserRegistrationForm(ModelFormWithCity, SubscriptionTypeFormMixin):
             raise forms.ValidationError(ugettext('Passwords are not the same'))
         return super(UserRegistrationForm, self).clean(*args, **kwargs)
 
+    @staticmethod
+    def save_custom_field(user, name, value, entity_field):
+        ContactProfileCustomField.objects.create(
+            profile=user.contactprofile,
+            name=name,
+            value=value,
+            entity_field=entity_field
+        )
+
     def save(self, commit=True):
         email = self.cleaned_data["email"]
         username = email[:30]
