@@ -36,12 +36,8 @@ from balafon.Search.forms import (
 
 def filter_icontains_unaccent(queryset, field, text):
     if crm_settings.is_unaccent_filter_supported():
-        queryset = queryset.extra(
-            where=["UPPER(unaccent("+field+")) LIKE UPPER(unaccent(%s))"],
-            params=["%{0}%".format(text)]
-        )
-        return list(queryset)
-    return list(queryset.filter(**{field+"__icontains": text}))
+        field += '__unaccent'
+    return list(queryset.filter(**{field + "__icontains": text}))
 
 
 @csrf_exempt
@@ -295,12 +291,14 @@ def create_emailing(request):
                 form = NewEmailingForm(request.POST)
                 if form.is_valid():
                     newsletter_id = form.cleaned_data['newsletter']
+                    subscription_type = form.cleaned_data['subscription_type']
                     if newsletter_id:
                         newsletter = Newsletter.objects.get(id=newsletter_id)
                     else:
-                        newsletter = Newsletter.objects.create(subject=form.cleaned_data['subject'])
-
-                    subscription_type = form.cleaned_data['subscription_type']
+                        newsletter = Newsletter.objects.create(
+                            subject=form.cleaned_data['subject'],
+                            site=subscription_type.site
+                        )
 
                     contacts = form.get_contacts()
 
@@ -356,7 +354,7 @@ def export_contacts_as_excel(request):
             fields = [
                 'id', 'get_gender_text', 'lastname', 'firstname', 'title', 'get_entity_name', 'job', 'role',
                 'get_address', 'get_address2', 'get_address3', 'get_zip_code', 'get_cedex', 'get_city',
-                'get_foreign_country', 'mobile', 'get_phone', 'get_email', 'birth_date'
+                'get_foreign_country', 'mobile', 'get_phone', 'get_email', 'birth_date', 'favorite_language'
             ]
             
             # header
