@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-from floppyforms.widgets import TextInput
+import floppyforms.__future__ as forms
 
 
-class DatespanInput(TextInput):
+class DatespanInput(forms.TextInput):
     """widget with two dates"""
     template_name = 'Search/_datespan_widget.html'
