@@ -5,8 +5,8 @@ from datetime import datetime, timedelta
 import logging
 
 from django.contrib.auth.models import User
-from django.core.urlresolvers import reverse
 from django.test.utils import override_settings
+from django.urls import reverse
 
 from model_mommy import mommy
 from rest_framework import status
@@ -262,7 +262,7 @@ class StoreItemApiTest(BaseTestCase):
         mommy.make(models.StoreItem)
 
         url = reverse('store_store-items-list') + "?ids={0}".format(
-            u','.join([str(id_) for id_ in (store_item1.id, store_item2.id)])
+            ','.join([str(id_) for id_ in (store_item1.id, store_item2.id)])
         )
 
         response = self.client.get(url, format='json')
@@ -307,7 +307,7 @@ class StoreItemApiTest(BaseTestCase):
         store_item1 = mommy.make(models.StoreItem)
 
         url = reverse('store_store-items-list') + "?ids={0}".format(
-            u','.join([str(id_) for id_ in (store_item1.id, store_item1.id + 1)])
+            ','.join([str(id_) for id_ in (store_item1.id, store_item1.id + 1)])
         )
 
         response = self.client.get(url, format='json')
@@ -342,7 +342,7 @@ class StoreItemApiTest(BaseTestCase):
         mommy.make(models.StoreItem)
 
         url = reverse('store_store-items-list') + "?ids={0}".format(
-            u','.join([str(id_) for id_ in (store_item1.id, "hjhkhz")])
+            ','.join([str(id_) for id_ in (store_item1.id, "hjhkhz")])
         )
 
         response = self.client.get(url, format='json')
@@ -396,7 +396,7 @@ class StoreItemApiTest(BaseTestCase):
     def test_view_store_items_by_name2(self):
         """It should return only items of name"""
 
-        for i in xrange(25):
+        for i in range(25):
             mommy.make(models.StoreItem, name="Abc{0}".format(i))
 
         url = reverse('store_store-items-list') + "?name=Abc"
@@ -669,8 +669,8 @@ class LastSalesApiTest(BaseTestCase):
         store_item1 = mommy.make(models.StoreItem)
         mommy.make(models.StoreItem)
 
-        self.user.first_name = u'John'
-        self.user.last_name = u'Doe'
+        self.user.first_name = 'John'
+        self.user.last_name = 'Doe'
         self.user.save()
 
         profile = create_profile_contact(self.user)
@@ -698,13 +698,13 @@ class LastSalesApiTest(BaseTestCase):
     def test_view_last_sales_not_published(self):
         """It should return one store item"""
 
-        store_item1 = mommy.make(models.StoreItem, name=u'Orange')
-        store_item2 = mommy.make(models.StoreItem, name=u'Banana')
-        store_item3 = mommy.make(models.StoreItem, name=u'Apple', published=False)
+        store_item1 = mommy.make(models.StoreItem, name='Orange')
+        store_item2 = mommy.make(models.StoreItem, name='Banana')
+        store_item3 = mommy.make(models.StoreItem, name='Apple', published=False)
         store_item4 = mommy.make(models.StoreItem)
 
-        self.user.first_name = u'John'
-        self.user.last_name = u'Doe'
+        self.user.first_name = 'John'
+        self.user.last_name = 'Doe'
         self.user.save()
 
         profile = create_profile_contact(self.user)
@@ -750,13 +750,13 @@ class LastSalesApiTest(BaseTestCase):
     def test_view_last_sales_only_two_sales(self):
         """It should return three store item"""
 
-        store_item1 = mommy.make(models.StoreItem, name=u'Orange')
-        store_item2 = mommy.make(models.StoreItem, name=u'Banana')
-        store_item3 = mommy.make(models.StoreItem, name=u'Apple')
+        store_item1 = mommy.make(models.StoreItem, name='Orange')
+        store_item2 = mommy.make(models.StoreItem, name='Banana')
+        store_item3 = mommy.make(models.StoreItem, name='Apple')
         store_item4 = mommy.make(models.StoreItem)
 
-        self.user.first_name = u'John'
-        self.user.last_name = u'Doe'
+        self.user.first_name = 'John'
+        self.user.last_name = 'Doe'
         self.user.save()
 
         profile = create_profile_contact(self.user)
