@@ -100,7 +100,7 @@ class CartTest(BaseTestCase):
         self.assertEqual(action.subject, '')
         self.assertEqual(action.detail, '')
         self.assertEqual(action.planned_date, data['purchase_datetime'])
-
+        self.assertEqual(action.sale.payment_mode, None)
         self.assertEqual(action.sale.analysis_code, models.SaleAnalysisCode.objects.get(name='Internet'))
 
         self.assertEqual(action.sale.saleitem_set.count(), 2)
@@ -126,6 +126,141 @@ class CartTest(BaseTestCase):
         store_item2 = models.StoreItem.objects.get(id=store_item2.id)
         self.assertEqual(store_item2.stock_count, None)
 
+    def test_post_cart_payment_mode(self):
+        """It should create a new sale and action"""
+
+        # Create contact for the user
+        profile = create_profile_contact(self.user)
+        contact = profile.contact
+
+        store_item1 = mommy.make(models.StoreItem)
+        store_item2 = mommy.make(models.StoreItem)
+
+        delivery_point = mommy.make(models.DeliveryPoint)
+        payment_mode1 = mommy.make(models.PaymentMode)
+        payment_mode2 = mommy.make(models.PaymentMode)
+
+        data = {
+            'items': [
+                {'id': store_item1.id, 'quantity': 2},
+                {'id': store_item2.id, 'quantity': 1},
+            ],
+            'delivery_point': delivery_point.id,
+            'purchase_datetime': datetime(2015, 7, 23, 12, 0),
+            'payment_mode': payment_mode1.id,
+        }
+
+        url = reverse('store_post_cart')
+
+        response = self.client.post(url, data, format='json')
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+        self.assertEqual(response.data['ok'], True)
+        self.assertEqual(len(response.data['warnings']), 0)
+        self.assertEqual(response.data['deliveryDate'], data['purchase_datetime'])
+        self.assertEqual(response.data['deliveryPlace'], delivery_point.name)
+
+        action_type = ActionType.objects.get(name=get_cart_type_name())
+
+        action_queryset = Action.objects.filter(type=action_type)
+        self.assertEqual(action_queryset.count(), 1)
+        action = action_queryset[0]
+
+        self.assertEqual(response.data['action'], action.id)
+
+        self.assertEqual(list(action.contacts.all()), [contact])
+        self.assertEqual(action.subject, '')
+        self.assertEqual(action.detail, '')
+        self.assertEqual(action.planned_date, data['purchase_datetime'])
+
+        self.assertEqual(action.sale.payment_mode, payment_mode1)
+        self.assertEqual(action.sale.analysis_code, models.SaleAnalysisCode.objects.get(name='Internet'))
+
+        self.assertEqual(action.sale.saleitem_set.count(), 2)
+        self.assertEqual(action.sale.saleitem_set.all()[0].item, store_item1)
+        self.assertEqual(action.sale.saleitem_set.all()[0].text, store_item1.name)
+        self.assertEqual(action.sale.saleitem_set.all()[0].unit_price(), store_item1.pre_tax_price)
+        self.assertEqual(action.sale.saleitem_set.all()[0].vat_rate, store_item1.vat_rate)
+        self.assertEqual(action.sale.saleitem_set.all()[0].quantity, 2)
+
+        self.assertEqual(action.sale.saleitem_set.all()[1].item, store_item2)
+        self.assertEqual(action.sale.saleitem_set.all()[1].text, store_item2.name)
+        self.assertEqual(action.sale.saleitem_set.all()[1].unit_price(), store_item2.pre_tax_price)
+        self.assertEqual(action.sale.saleitem_set.all()[1].vat_rate, store_item2.vat_rate)
+        self.assertEqual(action.sale.saleitem_set.all()[1].quantity, 1)
+
+        self.assertEqual(len(mail.outbox), 2)
+        self.assertEqual(mail.outbox[0].to, [profile.contact.email])
+        self.assertEqual(mail.outbox[1].to, [settings.BALAFON_NOTIFICATION_EMAIL])
+
+        store_item1 = models.StoreItem.objects.get(id=store_item1.id)
+        self.assertEqual(store_item1.stock_count, None)
+
+        store_item2 = models.StoreItem.objects.get(id=store_item2.id)
+        self.assertEqual(store_item2.stock_count, None)
+
+    def test_post_cart_payment_mode_none(self):
+        """It should create a new sale and action"""
+
+        # Create contact for the user
+        profile = create_profile_contact(self.user)
+        contact = profile.contact
+
+        store_item1 = mommy.make(models.StoreItem)
+        store_item2 = mommy.make(models.StoreItem)
+
+        delivery_point = mommy.make(models.DeliveryPoint)
+        payment_mode1 = mommy.make(models.PaymentMode)
+        payment_mode2 = mommy.make(models.PaymentMode)
+
+        data = {
+            'items': [
+                {'id': store_item1.id, 'quantity': 2},
+                {'id': store_item2.id, 'quantity': 1},
+            ],
+            'delivery_point': delivery_point.id,
+            'purchase_datetime': datetime(2015, 7, 23, 12, 0),
+            'payment_mode': None,
+        }
+
+        url = reverse('store_post_cart')
+
+        response = self.client.post(url, data, format='json')
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.data['ok'], False)
+        self.assertEqual(models.Sale.objects.count(), 0)
+
+    def test_post_cart_payment_mode_invalid(self):
+        """It should create a new sale and action"""
+
+        # Create contact for the user
+        profile = create_profile_contact(self.user)
+        contact = profile.contact
+
+        store_item1 = mommy.make(models.StoreItem)
+        store_item2 = mommy.make(models.StoreItem)
+
+        delivery_point = mommy.make(models.DeliveryPoint)
+        payment_mode1 = mommy.make(models.PaymentMode)
+        payment_mode2 = mommy.make(models.PaymentMode)
+
+        data = {
+            'items': [
+                {'id': store_item1.id, 'quantity': 2},
+                {'id': store_item2.id, 'quantity': 1},
+            ],
+            'delivery_point': delivery_point.id,
+            'purchase_datetime': datetime(2015, 7, 23, 12, 0),
+            'payment_mode': payment_mode2.id + 1,
+        }
+
+        url = reverse('store_post_cart')
+
+        response = self.client.post(url, data, format='json')
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.data['ok'], False)
+        self.assertEqual(models.Sale.objects.count(), 0)
+
     @override_settings(BALAFON_CART_CONFIRMATION_EMAIL_SUBJECT="Hello")
     def test_post_cart_email_subject(self):
         """It should create a new sale and action"""
@@ -789,6 +924,7 @@ class CartTest(BaseTestCase):
 
 
 @skipIf(not ("balafon.Profile" in settings.INSTALLED_APPS), "registration not installed")
+@override_settings(BALAFON_NOTIFICATION_EMAIL="toto@toto.fr")
 class VoucherTest(BaseTestCase):
     """voucher calculated"""
 
@@ -890,6 +1026,104 @@ class VoucherTest(BaseTestCase):
 
         self.assertEqual(action.sale.vat_incl_total_price(), Decimal('367.2'))
 
+    def test_post_voucher_digits(self):
+        """It should create a new sale and action"""
+
+        # Create contact for the user
+        profile = create_profile_contact(self.user)
+        contact = profile.contact
+        vat_rate1 = mommy.make(models.VatRate, rate=Decimal(20))
+        store_item1 = mommy.make(models.StoreItem, pre_tax_price=Decimal('120'), vat_rate=vat_rate1)
+        store_item2 = mommy.make(models.StoreItem, pre_tax_price=Decimal('100'), vat_rate=vat_rate1)
+
+        delivery_point = mommy.make(models.DeliveryPoint)
+
+        today = date.today()
+        voucher = mommy.make(
+            models.Voucher, active=True, code='abc', start_date=today, end_date=today, rate=Decimal('12.50')
+        )
+
+        data = {
+            'items': [
+                {'id': store_item1.id, 'quantity': 2},
+                {'id': store_item2.id, 'quantity': 1},
+            ],
+            'voucher_code': voucher.code,
+        }
+        url = reverse('store_voucher')
+        response = self.client.post(url, data, format='json')
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.data['voucher_code'], voucher.code)
+        self.assertEqual(response.data['label'], voucher.label)
+        self.assertEqual(Decimal(response.data['discount']), Decimal('51'))
+
+        data = {
+            'items': [
+                {'id': store_item1.id, 'quantity': 2},
+                {'id': store_item2.id, 'quantity': 1},
+            ],
+            'delivery_point': delivery_point.id,
+            'purchase_datetime': datetime(2015, 7, 23, 12, 0),
+            'voucher_code': voucher.code,
+        }
+
+        url = reverse('store_post_cart')
+
+        response = self.client.post(url, data, format='json')
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+        self.assertEqual(response.data['ok'], True)
+        self.assertEqual(len(response.data['warnings']), 0)
+        self.assertEqual(response.data['deliveryDate'], data['purchase_datetime'])
+        self.assertEqual(response.data['deliveryPlace'], delivery_point.name)
+
+        action_type = ActionType.objects.get(name=get_cart_type_name())
+
+        action_queryset = Action.objects.filter(type=action_type)
+        self.assertEqual(action_queryset.count(), 1)
+        action = action_queryset[0]
+
+        self.assertEqual(response.data['action'], action.id)
+
+        self.assertEqual(list(action.contacts.all()), [contact])
+        self.assertEqual(action.subject, '')
+        self.assertEqual(action.detail, '')
+        self.assertEqual(action.planned_date, data['purchase_datetime'])
+
+        self.assertEqual(action.sale.analysis_code, models.SaleAnalysisCode.objects.get(name='Internet'))
+
+        self.assertEqual(action.sale.saleitem_set.count(), 3)
+        self.assertEqual(action.sale.saleitem_set.all()[0].item, store_item1)
+        self.assertEqual(action.sale.saleitem_set.all()[0].text, store_item1.name)
+        self.assertEqual(action.sale.saleitem_set.all()[0].unit_price(), store_item1.pre_tax_price)
+        self.assertEqual(action.sale.saleitem_set.all()[0].vat_rate, store_item1.vat_rate)
+        self.assertEqual(action.sale.saleitem_set.all()[0].quantity, 2)
+
+        self.assertEqual(action.sale.saleitem_set.all()[1].item, store_item2)
+        self.assertEqual(action.sale.saleitem_set.all()[1].text, store_item2.name)
+        self.assertEqual(action.sale.saleitem_set.all()[1].unit_price(), store_item2.pre_tax_price)
+        self.assertEqual(action.sale.saleitem_set.all()[1].vat_rate, store_item2.vat_rate)
+        self.assertEqual(action.sale.saleitem_set.all()[1].quantity, 1)
+
+        voucher_text = voucher.label
+        self.assertEqual(action.sale.saleitem_set.all()[2].item, None)
+        self.assertEqual(action.sale.saleitem_set.all()[2].text, voucher_text)
+        self.assertEqual(action.sale.saleitem_set.all()[2].unit_price(), -Decimal('42.5'))
+        self.assertEqual(action.sale.saleitem_set.all()[2].vat_rate, store_item1.vat_rate)
+        self.assertEqual(action.sale.saleitem_set.all()[2].quantity, 1)
+
+        self.assertEqual(len(mail.outbox), 2)
+        self.assertEqual(mail.outbox[0].to, [profile.contact.email])
+        self.assertEqual(mail.outbox[1].to, [settings.BALAFON_NOTIFICATION_EMAIL])
+
+        store_item1 = models.StoreItem.objects.get(id=store_item1.id)
+        self.assertEqual(store_item1.stock_count, None)
+
+        store_item2 = models.StoreItem.objects.get(id=store_item2.id)
+        self.assertEqual(store_item2.stock_count, None)
+
+        self.assertEqual(action.sale.vat_incl_total_price(), Decimal('357'))
+
     def test_post_voucher_two_vat(self):
         """It should create a new sale and action"""
 
