@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Balafon : your django CRM"""
 
-import floppyforms as forms
+import floppyforms.__future__ as forms
 
 
 class HidableModelMultipleChoiceField(forms.ModelMultipleChoiceField):
